@@ -6,7 +6,7 @@ from urllib3.util.retry import Retry
 from syncari.logger import SyncariLogger
 from syncari.models.request import ErrorResponse
 
-logger = SyncariLogger.get_logger('rest_client')
+logger = SyncariLogger().get_logger('rest_client')
 
 class RetryableException(Exception):
     """Class to mark an ApiException as retryable."""
