@@ -41,8 +41,8 @@ class Synapse(ABC):
         self.logger.info(self.raw_request)
         response = None
         try:
-            if self.request_type == RequestType.CONNECT:
-                response = self.connect()
+            if self.request_type == RequestType.TEST:
+                response = self.test()
                 if not isinstance(response, Connection):
                     raise self.__prep_invalid_response_exception(response)
 
@@ -153,14 +153,14 @@ class Synapse(ABC):
 
     @property
     def logger(self):
-        return SyncariLogger.get_logger(f"{self.name}")
+        return SyncariLogger().get_logger(f"{self.name}")
 
     @abstractmethod
     def synapse_info(self):
         pass
 
     @abstractmethod
-    def connect(self):
+    def test(self):
         pass
 
     @abstractmethod
