@@ -1,10 +1,9 @@
 # pylint: disable=missing-class-docstring, import-error, missing-function-docstring
-from flask import jsonify
 from pytest import fail
 from syncari.rest.client import SyncariException, SyncariRestClient
 from syncari.logger import SyncariLogger
 
-logger = SyncariLogger.get_logger('test_router')
+logger = SyncariLogger().get_logger('test_router')
 
 def test_get():
     rest_client = SyncariRestClient('http://universities.hipolabs.com/', None)
